@@ -23,14 +23,7 @@ my $worksheet = $workbook->add_worksheet( 'Hyperlinks' );
 $worksheet->set_column( 'A:A', 30 );
 $worksheet->set_selection( 'B1' );
 
-
-# Add the standard url link format.
-my $url_format = $workbook->add_format(
-    color     => 'blue',
-    underline => 1,
-);
-
-# Add a sample format.
+# Add a user defined hyperlink format.
 my $red_format = $workbook->add_format(
     color     => 'red',
     bold      => 1,
@@ -45,13 +38,17 @@ my $str = 'Perl home.';
 my $tip = 'Get the latest Perl news here.';
 
 
-# Write some hyperlinks
-$worksheet->write( 'A1', 'http://www.perl.com/', $url_format );
-$worksheet->write( 'A3', 'http://www.perl.com/', $url_format, $str );
-$worksheet->write( 'A5', 'http://www.perl.com/', $url_format, $str, $tip );
+# Write some hyperlinks. Unspecified or undefined format paraamters will be
+# replace with the defuault Excel hyperlink style.
+$worksheet->write( 'A1', 'http://www.perl.com/' );
+$worksheet->write( 'A3', 'http://www.perl.com/', undef, $str );
+$worksheet->write( 'A5', 'http://www.perl.com/', undef, $str, $tip );
 $worksheet->write( 'A7', 'http://www.perl.com/', $red_format );
-$worksheet->write( 'A9', 'mailto:jmcnamara@cpan.org', $url_format, 'Mail me' );
+$worksheet->write( 'A9', 'mailto:jmcnamara@cpan.org', undef, 'Mail me' );
 
 # Write a URL that isn't a hyperlink
 $worksheet->write_string( 'A11', 'http://www.perl.com/' );
 
+$workbook->close();
+
+__END__
