@@ -5,7 +5,7 @@
 # A simple example of converting some Unicode text to an Excel file using
 # Excel::Writer::XLSX.
 #
-# This example generates some Greek from a file with ISO-8859-7 encoded text.
+# This example generates some Thai from a file with ISO-8859-11 encoded text.
 #
 #
 # reverse ('(c)'), September 2004, John McNamara, jmcnamara@cpan.org
@@ -16,7 +16,7 @@ use warnings;
 use Excel::Writer::XLSX;
 
 
-my $workbook = Excel::Writer::XLSX->new( 'unicode_8859_7.xlsx' );
+my $workbook = Excel::Writer::XLSX->new( 'unicode_8859_11.xlsx' );
 
 die "Couldn't create new Excel file: $!.\n" unless defined $workbook;
 
@@ -24,9 +24,9 @@ my $worksheet = $workbook->add_worksheet();
 $worksheet->set_column( 'A:A', 50 );
 
 
-my $file = 'unicode_8859_7.txt';
+my $file = 'unicode_8859_11.txt';
 
-open FH, '<:encoding(iso-8859-7)', $file or die "Couldn't open $file: $!\n";
+open FH, '<:encoding(iso-8859-11)', $file or die "Couldn't open $file: $!\n";
 
 my $row = 0;
 
@@ -36,6 +36,7 @@ while ( <FH> ) {
     $worksheet->write( $row++, 0, $_ );
 }
 
+$workbook->close();
 
 __END__
 
