@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 
 ###############################################################################
@@ -115,22 +115,6 @@ sub _write_pie_chart {
 }
 
 
-###############################################################################
-#
-# combine()
-#
-# Override parent method to add a warning.
-#
-sub combine {
-
-    my $self  = shift;
-    my $chart = shift;
-
-    carp "Combined chart not currently supported for Pie charts";
-    return;
-}
-
-
 ##############################################################################
 #
 # _write_plot_area().
@@ -143,6 +127,7 @@ sub combine {
 sub _write_plot_area {
 
     my $self = shift;
+    my $second_chart = $self->{_combined};
 
     $self->xml_start_tag( 'c:plotArea' );
 
@@ -152,6 +137,27 @@ sub _write_plot_area {
     # Write the subclass chart type element.
     $self->_write_chart_type();
 
+    # Configure a combined chart if present.
+    if ( $second_chart ) {
+
+        # Secondary axis has unique id otherwise use same as primary.
+        if ( $second_chart->{_is_secondary} ) {
+            $second_chart->{_id} = 1000 + $self->{_id};
+        }
+        else {
+            $second_chart->{_id} = $self->{_id};
+        }
+
+        # Shart the same filehandle for writing.
+        $second_chart->{_fh} = $self->{_fh};
+
+        # Share series index with primary chart.
+        $second_chart->{_series_index} = $self->{_series_index};
+
+        # Write the subclass chart type elements for combined chart.
+        $second_chart->_write_chart_type();
+    }
+
     # Write the c:spPr element for the plotarea formatting.
     $self->_write_sp_pr( $self->{_plotarea} );
 
